#
# spec file for package opencdk
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           opencdk
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
Url:            http://www.gnutls.org/
Version:        0.6.6
Release:        32.3
Summary:        Library Providing Basic Parts of the OpenPGP Message Format
License:        GPL-2.0+
Group:          System/Libraries
Source:         %{name}-%{version}.tar.bz2
Source2:        baselibs.conf
Patch:          opencdk-0.6.6-remove_pointer_comparison.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
For reference, read RFC2440. Due to some possible security problems,
the library also implements parts of
draft-ietf-openpgp-rfc2440bis-06.txt.

The aim of the library is not to replace any available OpenPGP version.
There is no real support for key management (sign, revoke, alter
preferences, etc.) and some other parts are only rudimentarily
available. The main purpose is to handle and understand OpenPGP packets
and to use basic operations. For example, to encrypt and decrypt, sign
and verify, and provide packet routines.

%package -n libopencdk10
Summary:        Library Providing Basic Parts of the OpenPGP Message Format
Group:          System/Libraries
# libopencdk last used in 10.3
Provides:       libopencdk = %{version}
Obsoletes:      libopencdk < %{version}
# provide for debuginfo package (always requiring main package name)
Provides:       opencdk = %{version}-%{release}

%description -n libopencdk10
For reference, read RFC2440. Due to some possible security problems,
the library also implements parts of
draft-ietf-openpgp-rfc2440bis-06.txt.

The aim of the library is not to replace any available OpenPGP version.
There is no real support for key management (sign, revoke, alter
preferences, etc.) and some other parts are only rudimentarily
available. The main purpose is to handle and understand OpenPGP packets
and to use basic operations. For example, to encrypt and decrypt, sign
and verify, and provide packet routines.

%package -n libopencdk-devel
Summary:        Development tools for programs which will use the opencdk library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libgcrypt-devel
Requires:       libgpg-error-devel
Requires:       libopencdk10 = %{version}
Requires:       zlib-devel

%description -n libopencdk-devel
This package contains the header files and static libraries for
developing programs which will be linked against the opencdk library.

%prep
%setup -q
%patch -p1

%build
autoreconf --force --install
CFLAGS="$RPM_OPT_FLAGS" ./configure \
		--prefix=%{_prefix} \
		--sysconfdir=%_sysconfdir \
		--libdir=%{_libdir}
make %{?_smp_mflags}

%check
#won't work in build service as it requires strong random, and the xen build instances
#do not generate enough noise for random. I don't see a way to reconfigure libcrypt
#to use weak random for testing - possibly the build service chroot should have
#random point to urandom, but for now it should simply build
#make check

%install
make DESTDIR=$RPM_BUILD_ROOT install
install -m 755 -d %buildroot/%_datadir/aclocal/
install -m 644 src/opencdk.m4 %buildroot/%_datadir/aclocal/
# don't package static lib and libtool la file
rm -f %{buildroot}/%{_libdir}/libopencdk.{a,la}

%post -n libopencdk10
/sbin/ldconfig

%postun -n libopencdk10
/sbin/ldconfig

%files -n libopencdk10
%defattr(-,root,root)
%_libdir/libopencdk.so.10*

%files -n libopencdk-devel
%defattr(-,root,root)
%doc TODO THANKS README NEWS ChangeLog COPYING AUTHORS
%doc doc/opencdk-api.html
%_bindir/opencdk-config
%_libdir/libopencdk.so
%_includedir/opencdk.h
%_datadir/aclocal/*
%_libdir/pkgconfig/opencdk.pc

%changelog
* Sat Jan 12 2013 coolo@suse.com
- remove suse_update_config
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Wed Dec 16 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Sat Jun 20 2009 coolo@novell.com
- disable %%check again
* Tue Oct  7 2008 mkoenig@suse.de
- enable self test
- remove bogus pointer comparison [bnc#432619]
* Mon Jun 30 2008 mkoenig@suse.de
- update to version 0.6.6
  * Cleanups for the key export and import functionality
  * Clarified the semantic of cdk_pk_check_sigs
  * Now the by usage keydb function correctly finds the
    self signature
* Sun May 11 2008 coolo@suse.de
- fix rename of xxbit packages
* Fri May  9 2008 schwab@suse.de
- Use autoreconf --install.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Dec  5 2007 ro@suse.de
- provide main package name in library package for debuginfo
* Tue Oct 23 2007 mkoenig@suse.de
- update to version 0.6.4
- change package layout to conform shlib policy
  rename source package: libopencdk -> opencdk
  new subpackage: libopencdk10
* Mon Apr  2 2007 rguenther@suse.de
- add zlib-devel BuildRequires
* Tue Jan 23 2007 mkoenig@suse.de
- update to version 0.5.11:
  * Add a new self test "basic" to test cdk_check_version
  * Add prototype of cdk_stream_decrypt to opencdk.h
  * Fix crash in cdk_data_transform triggered by self-tests
* Wed Oct 11 2006 mkoenig@suse.de
- update to version 0.5.10:
  * Fix double-free in cdk_pklist_encrypt
  * Fix keydb_idx_search() to handle keys at offset 0
  * A pkg-config script was added
* Thu Aug 31 2006 mkoenig@suse.de
- update to version 0.5.9 (minor bugfix release)
- added libgcrypt-devel, glibc-devel, libgpg-error-devel and
  zlib-devel to Requires tag of devel subpackage.
* Mon Jul 31 2006 mskibbe@suse.de
- fix a compiler warning see bug #177157 - libopencdk-0.5.5-13:
  local variable used before set
* Wed Jul 12 2006 mskibbe@suse.de
- update to version 0.5.8 which
  o includes patch libopencdk-acquotation.diff
  o simplify
  o add some tests for configure
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Aug 31 2004 kukuk@suse.de
- Update to version 0.5.5
* Mon Aug 30 2004 kukuk@suse.de
- Create devel sub-package
* Thu Jul 15 2004 hvogel@suse.de
- add libgcrypt-devel and lipgpg-error-devel to nfb
* Wed May 19 2004 hvogel@suse.de
- update to version 0.5.4
* Tue Feb 17 2004 hvogel@suse.de
- initial package, version 0.5.3
